@@ -8,14 +8,19 @@ from mito_ai.completions.prompt_builders.prompt_constants import (
     VARIABLES_SECTION_HEADING,
     cell_update_output_str
 )
-from mito_ai.completions.prompt_builders.utils import get_rules_str
+from mito_ai.completions.prompt_builders.utils import (
+    get_rules_str,
+    get_selected_context_str,
+)
+
 
 def create_agent_execution_prompt(md: AgentExecutionMetadata) -> str:
     variables_str = '\n'.join([f"{variable}" for variable in md.variables or []])
     files_str = '\n'.join([f"{file}" for file in md.files or []])
     ai_optimized_cells_str = '\n'.join([f"{cell}" for cell in md.aiOptimizedCells or []])
-    rules_str = get_rules_str(md.selectedRules)
-    
+    rules_str = get_rules_str(md.additionalContext)
+    selected_context_str = get_selected_context_str(md.additionalContext)
+        
     context_str = f"""Remember to choose the correct tool to respond with.
 
 {rules_str}
@@ -30,6 +35,8 @@ def create_agent_execution_prompt(md: AgentExecutionMetadata) -> str:
 {FILES_SECTION_HEADING}
 {files_str}
 
+{selected_context_str}
+
 {cell_update_output_str(md.base64EncodedActiveCellOutput is not None)}"""
 
     task_str = '' if md.input == '' else f"""Your task: 
