@@ -3,16 +3,22 @@
 
 from dataclasses import dataclass
 import json
-from typing import Any, Final
+from typing import Any, Final, Literal
 import tornado
 import os
 from jupyter_server.base.handlers import APIHandler
-from mito_ai.utils.telemetry_utils import log
+from mito_ai.utils.telemetry_utils import MITO_SERVER_KEY, USER_KEY, log
 
 
 class LogHandler(APIHandler):
     """Handler for logging"""
     
+    def initialize(self, key_type: Literal['mito_server_key', 'user_key']) -> None:
+        """Initialize the log handler"""
+        
+        # The key_type is required so that we know if we can log pro users
+        self.key_type = key_type
+        
     @tornado.web.authenticated
     def put(self) -> None:
         """Log an event"""
@@ -26,6 +32,7 @@ class LogHandler(APIHandler):
         log_event = data['log_event']
         params = data.get('params', {})
         
-        log(log_event, params)
+        key_type = MITO_SERVER_KEY if self.key_type == "mito_server_key" else USER_KEY
+        log(log_event, params, key_type=key_type)
 
 
