@@ -3,8 +3,11 @@
 
 from typing import Any
 import pytest
-from mito_ai.constants import ACTIVE_BASE_URL, MITO_PROD_BASE_URL, MITO_DEV_BASE_URL
-from mito_ai.constants import MITO_STREAMLIT_DEV_BASE_URL, MITO_STREAMLIT_TEST_BASE_URL, ACTIVE_STREAMLIT_BASE_URL
+from mito_ai.constants import (
+    ACTIVE_BASE_URL, MITO_PROD_BASE_URL, MITO_DEV_BASE_URL,
+    MITO_STREAMLIT_DEV_BASE_URL, MITO_STREAMLIT_TEST_BASE_URL, ACTIVE_STREAMLIT_BASE_URL,
+    COGNITO_CONFIG_DEV, ACTIVE_COGNITO_CONFIG,
+)
 
 
 def test_prod_lambda_url() -> Any:
@@ -29,4 +32,16 @@ def test_testenv_streamlit_url() -> Any:
 
 def test_streamlit_active_base_url() -> Any:
     """Make sure that the active streamlit base url is correct"""
-    assert ACTIVE_STREAMLIT_BASE_URL == MITO_STREAMLIT_TEST_BASE_URL
+    assert ACTIVE_STREAMLIT_BASE_URL == MITO_STREAMLIT_DEV_BASE_URL
+
+def test_cognito_config() -> Any:
+    """Make sure that the Cognito configuration is correct"""
+    expected_config = {
+        'TOKEN_ENDPOINT': 'https://mito-app-auth.auth.us-east-1.amazoncognito.com/oauth2/token',
+        'CLIENT_ID': '6ara3u3l8sss738hrhbq1qtiqf',
+        'CLIENT_SECRET': '',
+        'REDIRECT_URI': 'http://localhost:8888/lab'
+    }
+
+    assert COGNITO_CONFIG_DEV == expected_config
+    assert ACTIVE_COGNITO_CONFIG == COGNITO_CONFIG_DEV
