@@ -23,7 +23,6 @@ import { AgentExecutionStatus } from '../ChatTaskpane';
 interface ChatInputProps {
     app: JupyterFrontEnd;
     initialContent: string;
-    placeholder: string;
     onSave: (content: string, index?: number, additionalContext?: Array<{ type: string, value: string }>) => void;
     onCancel?: () => void;
     isEditing: boolean;
@@ -31,6 +30,10 @@ interface ChatInputProps {
     notebookTracker: INotebookTracker;
     agentModeEnabled: boolean;
     agentExecutionStatus?: AgentExecutionStatus;
+    operatingSystem?: string;
+    displayOptimizedChatHistoryLength?: number;
+    agentTargetNotebookPanelRef?: React.RefObject<any>;
+    isSignedUp?: boolean;
 }
 
 export interface ExpandedVariable extends Variable {
@@ -47,7 +50,6 @@ interface ContextItem {
 const ChatInput: React.FC<ChatInputProps> = ({
     app,
     initialContent,
-    placeholder,
     onSave,
     onCancel,
     isEditing,
@@ -55,9 +57,12 @@ const ChatInput: React.FC<ChatInputProps> = ({
     notebookTracker,
     agentModeEnabled = false,
     agentExecutionStatus = 'idle',
+    operatingSystem = 'mac',
+    displayOptimizedChatHistoryLength = 0,
+    agentTargetNotebookPanelRef,
+    isSignedUp = true,
 }) => {
     const [input, setInput] = useState(initialContent);
-    const [expandedVariables, setExpandedVariables] = useState<ExpandedVariable[]>([]);
     const textAreaRef = React.useRef<HTMLTextAreaElement>(null);
     const [activeCellID, setActiveCellID] = useState<string | undefined>(getActiveCellID(notebookTracker));
     const activeCellCode = getActiveCellCode(notebookTracker) || '';
@@ -66,13 +71,24 @@ const ChatInput: React.FC<ChatInputProps> = ({
     const [additionalContext, setAdditionalContext] = useState<ContextItem[]>([]);
     const [isDropdownFromButton, setIsDropdownFromButton] = useState(false);
 
-    const handleFileUploaded = (fileName: string): void => {
+    const handleFileUpload = (file: File): void => {
+        let uploadType: string;
+
+        if (file.type.startsWith('image/')) {
+            // If the file is an image, we want to preserve the file type.
+            // The type is used to display the image icon in the SelectedContextContainer,
+            // and is used to encode the image on the backend.
+            uploadType = file.type;
+        } else {
+            uploadType = 'file';
+        }
+
         // Add the uploaded file to the additional context
         setAdditionalContext(prev => [
             ...prev, {
-                type: 'file',
-                value: fileName,
-                display: fileName
+                type: uploadType,
+                value: file.name,
+                display: file.name
             }
         ]);
     };
@@ -106,9 +122,10 @@ const ChatInput: React.FC<ChatInputProps> = ({
         if (!textarea) return;
 
         textarea.style.minHeight = 'auto';
+        const maxHeight = 350;
         textarea.style.height = !textarea.value || resetHeight
             ? '80px'
-            : `${Math.max(80, textarea.scrollHeight)}px`;
+            : `${Math.min(maxHeight, Math.max(80, textarea.scrollHeight))}px`;
     };
 
     useEffect(() => {
@@ -232,26 +249,31 @@ const ChatInput: React.FC<ChatInputProps> = ({
     };
 
     const mapAdditionalContext = (): Array<{ type: string, value: string }> => {
-        return additionalContext.map(context => {
-            if (context.type === 'db') {
-                return {
-                    type: context.type,
-                    value: context.value
-                };
+        const result: Array<{ type: string, value: string }> = [];
+
+        additionalContext.forEach(contextItem => {
+            if (contextItem.type === 'db') {
+                result.push({
+                    type: contextItem.type,
+                    value: contextItem.value
+                });
+            } else {
+                result.push(contextItem);
             }
-            return context;
         });
+
+        return result;
     };
 
-    // Update the expandedVariables arr when the variable manager changes
-    useEffect(() => {
+    const getExpandedVarialbes = (): ExpandedVariable[] => {
+        const activeNotebookContext = contextManager?.getActiveNotebookContext();
         const expandedVariables: ExpandedVariable[] = [
             // Add base variables (excluding DataFrames)
-            ...(contextManager?.variables.filter(variable => variable.type !== "pd.DataFrame") || []),
+            ...(activeNotebookContext?.variables.filter(variable => variable.type !== "pd.DataFrame") || []),
             // Add DataFrames
-            ...(contextManager?.variables.filter((variable) => variable.type === "pd.DataFrame") || []),
+            ...(activeNotebookContext?.variables.filter((variable) => variable.type === "pd.DataFrame") || []),
             // Add series with parent DataFrame references
-            ...(contextManager?.variables
+            ...(activeNotebookContext?.variables
                 .filter((variable) => variable.type === "pd.DataFrame")
                 .flatMap((df) =>
                     Object.entries(df.value).map(([seriesName, _]) => ({
@@ -262,15 +284,33 @@ const ChatInput: React.FC<ChatInputProps> = ({
                     }))
                 ) || []),
             // Add files
-            ...(contextManager?.files.map(file => ({
+            ...(activeNotebookContext?.files.map(file => ({
                 variable_name: file.file_name,
                 type: file.file_name.split('.').pop()?.toLowerCase() || '',
                 value: file.file_name,
                 file_name: file.file_name
             })) || [])
         ];
-        setExpandedVariables(expandedVariables);
-    }, [contextManager?.variables, contextManager?.files]);
+        return expandedVariables;
+    }
+
+    const getPlaceholderText = (): string => {
+        if (!isSignedUp && displayOptimizedChatHistoryLength === 0) {
+            return 'Sign up above to use Mito AI';
+        } else if (agentExecutionStatus === 'working') {
+            return `Agent is editing ${agentTargetNotebookPanelRef?.current?.context.path.split('/').pop()}`;
+        } else if (agentExecutionStatus === 'stopping') {
+            return 'Agent is stopping...';
+        } else if (agentModeEnabled) {
+            return 'Ask agent to do anything';
+        } else if (isEditing) {
+            return 'Edit your message';
+        } else if (displayOptimizedChatHistoryLength < 2) {
+            return `Ask question (${operatingSystem === 'mac' ? '⌘' : 'Ctrl'}E), @ to mention`;
+        } else {
+            return `Ask followup (${operatingSystem === 'mac' ? '⌘' : 'Ctrl'}E), @ to mention`;
+        }
+    };
 
     // Automatically add active cell context when in Chat mode and there's active cell code
     useEffect(() => {
@@ -296,11 +336,11 @@ const ChatInput: React.FC<ChatInputProps> = ({
 
     return (
         <div
-            className={classNames("chat-input-container")}
+            className={classNames("chat-input-container", { "editing": isEditing })}
         >
             <div className='context-container'>
                 <DatabaseButton app={app} />
-                <AttachFileButton onFileUploaded={handleFileUploaded} notebookTracker={notebookTracker} />
+                <AttachFileButton onFileUploaded={handleFileUpload} notebookTracker={notebookTracker} />
                 <button
                     className="context-button"
                     onClick={() => {
@@ -334,7 +374,7 @@ const ChatInput: React.FC<ChatInputProps> = ({
                 <textarea
                     ref={textAreaRef}
                     className={classNames("message", "message-user", 'chat-input', { "agent-mode": agentModeEnabled })}
-                    placeholder={placeholder}
+                    placeholder={getPlaceholderText()}
                     value={input}
                     disabled={agentExecutionStatus === 'working' || agentExecutionStatus === 'stopping'}
                     onChange={handleInputChange}
@@ -370,7 +410,7 @@ const ChatInput: React.FC<ChatInputProps> = ({
                 />
                 {isDropdownVisible && (
                     <ChatDropdown
-                        options={expandedVariables}
+                        options={getExpandedVarialbes()}
                         onSelect={handleOptionSelect}
                         filterText={dropdownFilter}
                         isDropdownFromButton={isDropdownFromButton}
