@@ -128,7 +128,6 @@ const ChatMessage: React.FC<IChatMessageProps> = ({
             <ChatInput
                 app={app}
                 initialContent={(message.content as string).replace(/```[\s\S]*?```/g, '').trim()}
-                placeholder={"Edit your message"}
                 onSave={handleSave}
                 onCancel={handleCancel}
                 isEditing={isEditing}
@@ -200,7 +199,7 @@ const ChatMessage: React.FC<IChatMessageProps> = ({
                                     />
                                 )}
 
-                                {isLastAiMessage && isCodeComplete && codeReviewStatus === 'chatPreview' &&
+                                {!agentModeEnabled && isLastAiMessage && isCodeComplete && codeReviewStatus === 'chatPreview' &&
                                     <div className='chat-message-buttons'>
                                         <TextAndIconButton
                                             onClick={() => { previewAICode() }}
@@ -220,7 +219,7 @@ const ChatMessage: React.FC<IChatMessageProps> = ({
                                         />
                                     </div>
                                 }
-                                {isLastAiMessage && isCodeComplete && codeReviewStatus === 'codeCellPreview' &&
+                                {!agentModeEnabled && isLastAiMessage && isCodeComplete && codeReviewStatus === 'codeCellPreview' &&
                                     <div className='chat-message-buttons'>
                                         <TextButton
                                             onClick={() => { acceptAICode() }}
