@@ -10,6 +10,7 @@ import React, { useEffect, useRef, useState } from 'react';
 
 // JupyterLab imports
 import { JupyterFrontEnd } from '@jupyterlab/application';
+import { NotebookPanel } from '@jupyterlab/notebook';
 import { CodeCell } from '@jupyterlab/cells';
 import { CodeMirrorEditor } from '@jupyterlab/codemirror';
 import { INotebookTracker } from '@jupyterlab/notebook';
@@ -34,7 +35,7 @@ import GroupedErrorsAndFixes from '../../components/AgentComponents/ErrorFixupTo
 import DropdownMenu from '../../components/DropdownMenu';
 import IconButton from '../../components/IconButton';
 import LoadingCircle from '../../components/LoadingCircle';
-import LoadingDots from '../../components/LoadingDots';
+
 import { DEFAULT_MODEL } from '../../components/ModelSelector';
 import ModelSelector from '../../components/ModelSelector';
 import NextStepsPills from '../../components/NextStepsPills';
@@ -43,29 +44,33 @@ import ToggleButton from '../../components/ToggleButton';
 
 // Internal imports - Icons
 import { OpenIndicatorLabIcon } from '../../icons';
-import MitoLogo from '../../icons/MitoLogo';
 import UndoIcon from '../../icons/UndoIcon';
 
 // Internal imports - Utils
 import { acceptAndRunCellUpdate, retryIfExecutionError, runAllCells } from '../../utils/agentActions';
+import { classNames } from '../../utils/classNames';
 import { checkForBlacklistedWords } from '../../utils/blacklistedWords';
 import { createCheckpoint, restoreCheckpoint } from '../../utils/checkpoint';
 import { processChatHistoryForErrorGrouping, GroupedErrorMessages } from '../../utils/chatHistory';
 import { getCodeDiffsAndUnifiedCodeString, UnifiedDiffLine } from '../../utils/codeDiff';
 import {
     getActiveCellID,
-    getActiveCellOutput,
     getCellByID,
     getCellCodeByID,
     highlightCodeCell,
     scrollToCell,
     setActiveCellByID,
+    setActiveCellByIDInNotebookPanel,
     writeCodeToCellByID,
 } from '../../utils/notebook';
+import { getActiveCellOutput } from '../../utils/cellOutput';
 import { scrollToDiv } from '../../utils/scroll';
 import { getCodeBlockFromMessage, removeMarkdownCodeFormatting } from '../../utils/strings';
 import { OperatingSystem } from '../../utils/user';
 import { waitForNotebookReady } from '../../utils/waitForNotebookReady';
+import { getBase64EncodedCellOutputInNotebook } from './utils';
+import { logEvent } from '../../restAPI/RestAPI';
+import { checkUserSignupState } from '../../utils/userSignupState';
 
 // Internal imports - Websockets
 import type { CompletionWebsocketClient } from '../../websockets/completions/CompletionsWebsocketClient';
@@ -94,9 +99,11 @@ import {
 // Internal imports - Extensions
 import { IContextManager } from '../ContextManager/ContextManagerPlugin';
 import { COMMAND_MITO_AI_SETTINGS } from '../SettingsManager/SettingsManagerPlugin';
+import { captureCompletionRequest } from '../SettingsManager/profiler/ProfilerPage';
 
 // Internal imports - Chat components
 import CTACarousel from './CTACarousel';
+import SignUpForm from './SignUpForm';
 import { codeDiffStripesExtension } from './CodeDiffDisplay';
 import { getFirstMessageFromCookie } from './FirstMessage';
 import ChatInput from './ChatMessage/ChatInput';
@@ -109,7 +116,7 @@ import { ChatHistoryManager, IDisplayOptimizedChatItem, PromptType } from './Cha
 import '../../../style/button.css';
 import '../../../style/ChatTaskpane.css';
 import '../../../style/TextButton.css';
-import { getBase64EncodedCellOutput } from './utils';
+import LoadingDots from '../../components/LoadingDots';
 
 const AGENT_EXECUTION_DEPTH_LIMIT = 20
 
@@ -144,6 +151,7 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
     websocketClient,
 }) => {
 
+    const [isSignedUp, setIsSignedUp] = useState<boolean>(true);
     const [chatHistoryManager, setChatHistoryManager] = useState<ChatHistoryManager>(() => getDefaultChatHistoryManager(notebookTracker, contextManager));
     const chatHistoryManagerRef = useRef<ChatHistoryManager>(chatHistoryManager);
 
@@ -197,6 +205,7 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
         3. idle: the agent is idle
     */
     const [agentExecutionStatus, setAgentExecutionStatus] = useState<AgentExecutionStatus>('idle')
+    const agentTargetNotebookPanelRef = useRef<NotebookPanel | null>(null)
 
     // We use a ref to always access the most up-to-date value during a function's execution. Refs immediately reflect changes, 
     // unlike state variables, which are captured at the beginning of a function and may not reflect updates made during execution.
@@ -204,6 +213,9 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
 
     const streamingContentRef = useRef<string>('');
     const streamHandlerRef = useRef<((sender: CompletionWebsocketClient, chunk: ICompletionStreamChunk) => void) | null>(null);
+    
+    // Track active requests for cancellation
+    const activeRequestControllerRef = useRef<AbortController | null>(null);
 
     // State for managing next steps from responses
     // If the user hides the next steps, we keep them hidden until they re-open them
@@ -372,9 +384,10 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
         return newChatHistoryManager;
     }
 
+    // Main initialization effect - runs once on mount
     useEffect(() => {
         const initializeChatHistory = async (): Promise<void> => {
-            try {
+            try {                
                 // Check for saved model preference in localStorage
                 const storedConfig = localStorage.getItem('llmModelConfig');
                 let initialModel = DEFAULT_MODEL;
@@ -436,7 +449,9 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             }
         };
 
-        void initializeChatHistory();
+        void logEvent('opened_ai_chat_taskpane');
+        void initializeChatHistory(); 
+        void refreshUserSignupState(); // Get user signup state when the component first mounts
 
     }, [websocketClient]);
 
@@ -465,6 +480,12 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
 
     }, [chatHistoryManager]);
 
+    // Function to refresh user signup state using the shared helper
+    const refreshUserSignupState = async (): Promise<void> => {
+        const signupState = await checkUserSignupState();
+        setIsSignedUp(signupState.isSignedUp);
+    };
+
     // Scroll to bottom whenever chat history updates, but only if in follow mode
     useEffect(() => {
         if (autoScrollFollowMode) {
@@ -544,6 +565,10 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
     }
 
     const sendAgentSmartDebugMessage = async (errorMessage: string): Promise<void> => {
+        if (agentTargetNotebookPanelRef.current === null) {
+            return
+        }
+
         // Step 0: reset the state for a new message
         resetForNewMessage()
 
@@ -552,7 +577,11 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
 
         // Step 1: Create message metadata
         const newChatHistoryManager = getDuplicateChatHistoryManager()
-        const agentSmartDebugMessage = newChatHistoryManager.addAgentSmartDebugMessage(activeThreadIdRef.current, errorMessage)
+        const agentSmartDebugMessage = newChatHistoryManager.addAgentSmartDebugMessage(
+            activeThreadIdRef.current, 
+            errorMessage,
+            agentTargetNotebookPanelRef.current
+        )
         setChatHistoryManager(newChatHistoryManager);
         setLoadingAIResponse(true);
 
@@ -598,9 +627,16 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
         sendCellIDOutput: string | undefined = undefined,
         additionalContext?: Array<{type: string, value: string}>
     ): Promise<void> => {
+
         // Step 0: reset the state for a new message
         resetForNewMessage()
 
+        const agentTargetNotebookPanel = agentTargetNotebookPanelRef.current
+
+        if (agentTargetNotebookPanel === null) {
+            return
+        }
+
         // Step 1: Add the user's message to the chat history
         const newChatHistoryManager = getDuplicateChatHistoryManager()
 
@@ -609,12 +645,17 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             newChatHistoryManager.dropMessagesStartingAtIndex(messageIndex)
         }
 
-        const agentExecutionMetadata = newChatHistoryManager.addAgentExecutionMessage(activeThreadIdRef.current, input, additionalContext)
+        const agentExecutionMetadata = newChatHistoryManager.addAgentExecutionMessage(
+            activeThreadIdRef.current, 
+            agentTargetNotebookPanel,
+            input,
+            additionalContext
+        )
         if (messageIndex !== undefined) {
             agentExecutionMetadata.index = messageIndex
         }
 
-        agentExecutionMetadata.base64EncodedActiveCellOutput = await getBase64EncodedCellOutput(notebookTracker, sendCellIDOutput)
+        agentExecutionMetadata.base64EncodedActiveCellOutput = await getBase64EncodedCellOutputInNotebook(agentTargetNotebookPanel, sendCellIDOutput)
 
         setChatHistoryManager(newChatHistoryManager)
         setLoadingAIResponse(true);
@@ -698,6 +739,12 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
     const _sendMessageAndSaveResponse = async (
         completionRequest: ICompletionRequest, newChatHistoryManager: ChatHistoryManager
     ): Promise<boolean> => {
+        // Create AbortController for this request
+        const abortController = new AbortController();
+        activeRequestControllerRef.current = abortController;
+        
+        // Capture the completion request for debugging
+        captureCompletionRequest(completionRequest);
         if (completionRequest.stream) {
             // Reset the streaming response and set streaming state
             streamingContentRef.current = '';
@@ -763,6 +810,7 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
 
             try {
                 const aiResponse = await websocketClient.sendMessage<ICompletionRequest, ICompletionReply>(completionRequest);
+                
                 const content = aiResponse.items[0]?.content ?? '';
 
                 if (
@@ -791,7 +839,17 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             // NON-STREAMING RESPONSES
             // Once we move everything to streaming, we can remove everything in this else block
             try {
+                // Check if request was aborted before making the call
+                if (abortController.signal.aborted) {
+                    throw new Error('Request aborted');
+                }
+                
                 const aiResponse = await websocketClient.sendMessage<ICompletionRequest, ICompletionReply>(completionRequest);
+                
+                // Check if request was aborted after receiving response
+                if (abortController.signal.aborted) {
+                    throw new Error('Request aborted');
+                }
 
                 if (aiResponse.error) {
 
@@ -837,6 +895,12 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
                     }
                 }
             } catch (error) {
+                // Check if this was an abort error
+                if ((error as any).message === 'Request aborted') {
+                    // Don't show error message for aborted requests
+                    return false;
+                }
+                
                 addAIMessageFromResponseAndUpdateState(
                     (error as any).title ? (error as any).title : `${error}`,
                     'chat',
@@ -856,6 +920,11 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             }
         }
 
+        // Clean up AbortController
+        if (activeRequestControllerRef.current === abortController) {
+            activeRequestControllerRef.current = null;
+        }
+
         return true
     }
 
@@ -874,27 +943,46 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
         setChatHistoryManager(chatHistoryManager)
     }
 
-    const markAgentForStopping = (): void => {
-        // Signal that the agent should stop after current task
+    const markAgentForStopping = async (reason: 'userStop' | 'naturalConclusion' = 'naturalConclusion',): Promise<void> => {
+        // Signal that the agent should stop immediately
         shouldContinueAgentExecution.current = false;
-        // Update UI to show stopping state
-        setAgentExecutionStatus('stopping');
+        // Update state/UI
+        setAgentExecutionStatus('idle');
+        setLoadingAIResponse(false);
+
+        if (reason === 'userStop') {
+            // Immediately abort any ongoing requests
+            if (activeRequestControllerRef.current) {
+                activeRequestControllerRef.current.abort();
+                activeRequestControllerRef.current = null;
+            }
+
+            // Add feedback message based on reason
+            const newChatHistoryManager = getDuplicateChatHistoryManager();
+            addAIMessageFromResponseAndUpdateState(
+                "Agent stopped by user.",
+                'chat',
+                newChatHistoryManager
+            );
+
+            // Send stop message to backend
+            await websocketClient.sendMessage({
+                type: "stop_agent",
+                message_id: UUID.uuid4(),
+                metadata: {
+                    promptType: "stop_agent",
+                    threadId: activeThreadIdRef.current
+                },
+                stream: false
+            });
+        }
+        return;
     }
 
-    const finalizeAgentStop = (): void => {
-        // Notify user that agent has been stopped
-        shouldContinueAgentExecution.current = false;
-        const newChatHistoryManager = getDuplicateChatHistoryManager();
-        addAIMessageFromResponseAndUpdateState(
-            "Agent execution stopped. You can continue the conversation or start a new one.",
-            'chat',
-            newChatHistoryManager
-        );
-        // Reset agent to idle state
-        setAgentExecutionStatus('idle');
-    }
 
     const startAgentExecution = async (input: string, messageIndex?: number, additionalContext?: Array<{type: string, value: string}>): Promise<void> => {
+        agentTargetNotebookPanelRef.current = notebookTracker.currentWidget
+
         await createCheckpoint(app, setHasCheckpoint);
         setAgentExecutionStatus('working')
 
@@ -910,9 +998,10 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
 
         // Loop through each message in the plan and send it to the AI
         while (!isAgentFinished && agentExecutionDepth <= AGENT_EXECUTION_DEPTH_LIMIT) {
+
             // Check if we should continue execution
             if (!shouldContinueAgentExecution.current) {
-                finalizeAgentStop()
+                await markAgentForStopping()
                 break;
             }
 
@@ -944,7 +1033,7 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
                             'agent:execution',
                             chatHistoryManager
                         );
-                        finalizeAgentStop()
+                        await markAgentForStopping()
                         break;
                     }
                 }
@@ -952,20 +1041,30 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
 
             const agentResponse = aiDisplayOptimizedChatItem?.agentResponse
 
+            if (agentTargetNotebookPanelRef.current === null) {
+                // If the agent target notebook panel is not set, we don't know where to run the code so we stop
+                await markAgentForStopping();
+                isAgentFinished = true
+                break;
+            }
+
             if (agentResponse === undefined) {
                 // If the agent response is undefined, we need to send a message to the agent
+                await markAgentForStopping();
                 isAgentFinished = true
                 break;
             }
 
             if (agentResponse.type === 'finished_task') {
                 // If the agent told us that it is finished, we can stop
+                await markAgentForStopping();
                 isAgentFinished = true
                 break;
             }
 
             if (agentResponse.type === 'cell_update' && (agentResponse.cell_update === undefined || agentResponse.cell_update === null)) {
                 // If the agent's response is not formatted correctly, stop. This is for typechecking mostly
+                await markAgentForStopping();
                 isAgentFinished = true
                 break;
             }
@@ -974,22 +1073,15 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
                 // Run the code and handle any errors
                 await acceptAndRunCellUpdate(
                     agentResponse.cell_update,
-                    notebookTracker,
-                    app,
-                    previewAICodeToActiveCell,
-                    acceptAICode
+                    agentTargetNotebookPanelRef.current,
                 )
 
                 const status = await retryIfExecutionError(
-                    notebookTracker,
+                    agentTargetNotebookPanelRef.current,
                     app,
-                    getDuplicateChatHistoryManager,
-                    addAIMessageFromResponseAndUpdateState,
                     sendAgentSmartDebugMessage,
-                    previewAICodeToActiveCell,
-                    acceptAICode,
                     shouldContinueAgentExecution,
-                    finalizeAgentStop,
+                    markAgentForStopping,
                     chatHistoryManagerRef
                 )
 
@@ -1019,23 +1111,19 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             }
 
             if (agentResponse.type === 'run_all_cells') {
-                const result = await runAllCells(app, notebookTracker)
+                const result = await runAllCells(app, agentTargetNotebookPanelRef.current)
                 
                 // If run_all_cells resulted in an error, handle it through the error fixup process
                 if (!result.success && result.errorMessage && result.errorCellId) {
                     // Set the error cell as active so the error retry logic can work with it
-                    setActiveCellByID(notebookTracker, result.errorCellId)
+                    setActiveCellByIDInNotebookPanel(agentTargetNotebookPanelRef.current, result.errorCellId)
                     
                     const status = await retryIfExecutionError(
-                        notebookTracker,
+                        agentTargetNotebookPanelRef.current,
                         app,
-                        getDuplicateChatHistoryManager,
-                        addAIMessageFromResponseAndUpdateState,
                         sendAgentSmartDebugMessage,
-                        previewAICodeToActiveCell,
-                        acceptAICode,
                         shouldContinueAgentExecution,
-                        finalizeAgentStop,
+                        markAgentForStopping,
                         chatHistoryManagerRef
                     )
 
@@ -1063,7 +1151,8 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             )
         }
 
-        setAgentExecutionStatus('idle')
+        // Use markAgentForStopping for natural conclusion to ensure consistent cleanup
+        await markAgentForStopping();
     }
 
     const updateCodeDiffStripes = (aiMessage: OpenAI.ChatCompletionMessageParam | undefined, updateCellID: string): void => {
@@ -1082,7 +1171,6 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
         const aiGeneratedCodeCleaned = removeMarkdownCodeFormatting(aiGeneratedCode || '');
         const { unifiedCodeString, unifiedDiffs } = getCodeDiffsAndUnifiedCodeString(updateCellCode, aiGeneratedCodeCleaned)
 
-
         // Store the code cell ID where we write the code diffs so that we can
         // accept or reject the code diffs to the correct cell
         cellStateBeforeDiff.current = { codeCellID: updateCellID, code: updateCellCode }
@@ -1108,7 +1196,7 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             return
         }
 
-        scrollToCell(notebookTracker, activeCellID, undefined, 'end')
+        scrollToCell(notebookTracker.currentWidget, activeCellID, undefined, 'end')
         updateCodeDiffStripes(lastAIDisplayMessage.message, activeCellID)
         updateCellToolbarButtons()
     }
@@ -1219,9 +1307,6 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
         app.commands.addCommand(COMMAND_MITO_AI_SEND_AGENT_MESSAGE, {
             execute: async (args?: ReadonlyPartialJSONObject) => {
                 if (args?.input) {
-                    // Make sure we're in agent mode 
-                    console.log('Setting agent mode to true')
-
                     // If its not already in agent mode, start a new chat in agent mode
                     if (!agentModeEnabledRef.current) {
                         await startNewChat();
@@ -1381,7 +1466,8 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
     };
 
     return (
-        <div className="chat-taskpane">
+        // We disable the chat taskpane if the user is not signed up AND there are no chat history items
+        <div className={classNames('chat-taskpane', { 'disabled': !(isSignedUp || displayOptimizedChatHistory.length > 0) })}>
             <div className="chat-taskpane-header">
                 <div className="chat-taskpane-header-left">
                     <IconButton
@@ -1430,11 +1516,10 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             <div className="chat-messages" ref={chatMessagesRef}>
                 {displayOptimizedChatHistory.length === 0 &&
                     <div className="chat-empty-message">
-                        <div style={{ margin: '0 auto 8px', display: 'block', textAlign: 'center' }}>
-                            <MitoLogo width="60" height="30" />
-                        </div>
-                        <span style={{ display: 'block', textAlign: 'center', fontWeight: 'bold', fontSize: '20px', marginBottom: '15px' }}>Data Copilot</span>
-                        <CTACarousel app={app} />
+                        {isSignedUp === false 
+                            ? <SignUpForm onSignUpSuccess={refreshUserSignupState} /> 
+                            : <CTACarousel app={app} />
+                        }
                     </div>
                 }
                 {processedDisplayOptimizedChatHistory.map((displayOptimizedChat, index) => {
@@ -1541,13 +1626,6 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
                 <ChatInput
                     app={app}
                     initialContent={''}
-                    placeholder={
-                        agentExecutionStatus === 'working' ? 'Agent is working...' :
-                            agentExecutionStatus === 'stopping' ? 'Agent is stopping...' :
-                                agentModeEnabled ? 'Ask agent to do anything' :
-                                    displayOptimizedChatHistory.length < 2 ? `Ask question (${operatingSystem === 'mac' ? '⌘' : 'Ctrl'}E), @ to mention`
-                                        : `Ask followup (${operatingSystem === 'mac' ? '⌘' : 'Ctrl'}E), @ to mention`
-                    }
                     onSave={agentModeEnabled ? startAgentExecution : sendChatInputMessage}
                     onCancel={undefined}
                     isEditing={false}
@@ -1555,6 +1633,10 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
                     notebookTracker={notebookTracker}
                     agentModeEnabled={agentModeEnabled}
                     agentExecutionStatus={agentExecutionStatus}
+                    operatingSystem={operatingSystem}
+                    displayOptimizedChatHistoryLength={displayOptimizedChatHistory.length}
+                    agentTargetNotebookPanelRef={agentTargetNotebookPanelRef}
+                    isSignedUp={isSignedUp}
                 />
             </div>
             {agentExecutionStatus !== 'working' && agentExecutionStatus !== 'stopping' && (
@@ -1610,7 +1692,7 @@ const ChatTaskpane: React.FC<IChatTaskpaneProps> = ({
             {(agentExecutionStatus === 'working' || agentExecutionStatus === 'stopping') && (
                 <button
                     className="button-base button-red stop-agent-button"
-                    onClick={markAgentForStopping}
+                    onClick={() => void markAgentForStopping('userStop')}
                     disabled={agentExecutionStatus === 'stopping'}
                     data-testid="stop-agent-button"
                 >
