@@ -6,7 +6,7 @@
 import React, { useState, useEffect } from 'react';
 import '../../style/ModelSelector.css';
 import NucleausIcon from '../icons/NucleausIcon';
-import { CLAUDE_OPUS_DISPLAY_NAME, CLAUDE_OPUS_MODEL_NAME, CLAUDE_SONNET_DISPLAY_NAME, CLAUDE_SONNET_MODEL_NAME, GPT_DISPLAY_NAME, GPT_MODEL_NAME } from '../utils/models';
+import { CLAUDE_SONNET_DISPLAY_NAME, CLAUDE_SONNET_MODEL_NAME } from '../utils/models';
 
 interface ModelConfig {
   model: string;
@@ -18,9 +18,7 @@ interface ModelMapping {
 }
 
 const MODEL_MAPPINGS: ModelMapping[] = [
-  { displayName: GPT_DISPLAY_NAME, fullName: GPT_MODEL_NAME },
   { displayName: 'GPT 4.1', fullName: 'gpt-4.1' },
-  { displayName: CLAUDE_OPUS_DISPLAY_NAME, fullName: CLAUDE_OPUS_MODEL_NAME },
   { displayName: CLAUDE_SONNET_DISPLAY_NAME, fullName: CLAUDE_SONNET_MODEL_NAME },
   { displayName: 'Gemini 2.5 Pro', fullName: 'gemini-2.5-pro-preview-03-25' }
 ];
