@@ -14,14 +14,16 @@ export interface ButtonProps {
     onClick?: () => void;
     action?: string;
     title: string;
-    variant: 'green' | 'red' | 'gray' | 'purple';
+    variant: 'green' | 'red' | 'gray' | 'purple' | 'dark-purple';
     width: 'block' | 'fit-contents';
+    textAlign?: 'left' | 'center' | 'right';
+    className?: string;
 }
 
 // Text Button is just the basic Button Props, nothing else. 
 interface TextButtonProps extends ButtonProps {}
 
-const TextButton: React.FC<TextButtonProps> = ({ text, onClick, title, variant, width, action }) => {
+const TextButton: React.FC<TextButtonProps> = ({ text, onClick, title, variant, width, action, textAlign = 'center', className }) => {
 
     if (action) {
         return (
@@ -30,7 +32,9 @@ const TextButton: React.FC<TextButtonProps> = ({ text, onClick, title, variant,
                     "text-button-mito-ai", 
                     "button-base",
                     `button-${variant}`,
-                    `button-width-${width}`
+                    `button-width-${width}`,
+                    `text-align-${textAlign}`,
+                    className
                 )} onClick={onClick} title={title}>
                     {text}
                 </button>
@@ -43,7 +47,9 @@ const TextButton: React.FC<TextButtonProps> = ({ text, onClick, title, variant,
             "text-button-mito-ai", 
             "button-base",
             `button-${variant}`,
-            `button-width-${width}`
+            `button-width-${width}`,
+            `text-align-${textAlign}`,
+            className
         )} onClick={onClick} title={title}>
             {text}
         </button>
