@@ -7,13 +7,14 @@ import AiChatPlugin from './Extensions/AiChat/AiChatPlugin';
 import ContextManagerPlugin from './Extensions/ContextManager/ContextManagerPlugin';
 import ErrorMimeRendererPlugin from './Extensions/ErrorMimeRenderer/ErrorMimeRendererPlugin';
 import ToolbarButtonsPlugin from './Extensions/ToolbarButtons/ToolbarButtonsPlugin';
-import AppBuilderPlugin from './Extensions/AppBuilder/AppBuilderPlugin';
-import StreamlitPreviewPlugin from './Extensions/StreamlitPreview/StreamlitPreviewPlugin';
+import AppDeployPlugin from './Extensions/AppDeploy/AppDeployPlugin';
+import StreamlitPreviewPlugin from './Extensions/AppPreview/StreamlitPreviewPlugin';
 import { emptyCellPlaceholder } from './Extensions/emptyCell/EmptyCellPlugin';
 import { statusItem } from './Extensions/status';
 import SettingsManagerPlugin from './Extensions/SettingsManager/SettingsManagerPlugin';
 import { versionCheckPlugin } from './Extensions/VersionCheck';
 import NotebookFooterPlugin from './Extensions/NotebookFooter';
+import ManageAppsPlugin from "./Extensions/AppManager/ManageAppsPlugin"
 
 // This is the main entry point to the mito-ai extension. It must export all of the top level
 // extensions that we want to load.
@@ -21,12 +22,13 @@ export default [
   AiChatPlugin,
   ErrorMimeRendererPlugin,
   ContextManagerPlugin,
-  AppBuilderPlugin,
+  AppDeployPlugin,
   StreamlitPreviewPlugin,
   ToolbarButtonsPlugin,
   emptyCellPlaceholder,
   statusItem,
   SettingsManagerPlugin,
   versionCheckPlugin,
-  NotebookFooterPlugin
+  NotebookFooterPlugin,
+  ManageAppsPlugin
 ];
