@@ -3,6 +3,10 @@
  * Distributed under the terms of the GNU Affero General Public License v3.0 License.
  */
 
+import { requestAPI } from "./utils";
+import { StreamlitPreviewResponse } from "../Extensions/AppPreview/StreamlitPreviewPlugin";
+
+
 /************************************
 
 LOG ENDPOINTS
@@ -24,14 +28,12 @@ export const logEvent = async (logEvent: string, params?: Record<string, any>):
 }
 
 
-import { StreamlitPreviewResponse } from "../Extensions/StreamlitPreview/StreamlitPreviewPlugin";
 /************************************
 
 SETTINGS ENDPOINTS
 
 ************************************/
 
-import { requestAPI } from "./utils";
 
 export const getSetting = async (settingsKey: string): Promise<string | undefined> => {
 
@@ -111,10 +113,18 @@ STREAMLIT PREVIEW ENDPOINTS
 ************************************/
 
 
-export const startStreamlitPreview = async (notebookPath: string): Promise<StreamlitPreviewResponse> => {
+export const startStreamlitPreview = async(
+    notebookPath: string, 
+    force_recreate: boolean = false,
+    edit_prompt: string = ''
+): Promise<StreamlitPreviewResponse> => {
     const response = await requestAPI<StreamlitPreviewResponse>('streamlit-preview', {
         method: 'POST',
-        body: JSON.stringify({ notebook_path: notebookPath }),
+        body: JSON.stringify({ 
+            notebook_path: notebookPath, 
+            force_recreate: force_recreate,
+            edit_prompt: edit_prompt
+        })
     })
     
     if (response.error) {
@@ -132,4 +142,68 @@ export const stopStreamlitPreview = async (previewId: string): Promise<void> =>
     if (response.error) {
         throw new Error(response.error.message);
     }
+}
+
+/************************************
+
+USER ENDPOINTS
+
+************************************/
+
+export const getUserKey = async (key: string): Promise<string | undefined> => {
+    const resp = await requestAPI<{key: string, value: string}>(`user/${key}`)
+    if (resp.error) {
+        throw new Error(resp.error.message);
+    }
+
+    return resp.data?.value;
+}
+
+export const setUserKey = async (key: string, value: string): Promise<string> => {
+    const resp = await requestAPI<string>(`user/${key}`, {
+        method: 'PUT',
+        body: JSON.stringify({ value: value }),
+    })
+    if (resp.error) {
+        throw new Error(resp.error.message);
+    }
+    return resp.data || '';
+}
+
+/************************************
+
+CHAT HISTORY ENDPOINTS
+
+************************************/
+
+export interface ChatThreadMetadata {
+    thread_id: string;
+    name: string;
+    creation_ts: number;
+    last_interaction_ts: number;
+}
+
+export interface ChatThread {
+    thread_id: string;
+    name: string;
+    creation_ts: number;
+    last_interaction_ts: number;
+    display_history: Array<{role: string, content: string}>;
+    ai_optimized_history: Array<{role: string, content: string}>;
+}
+
+export const getChatHistoryThreads = async (): Promise<ChatThreadMetadata[]> => {
+    const resp = await requestAPI<{threads: ChatThreadMetadata[]}>('chat-history/threads')
+    if (resp.error) {
+        throw new Error(resp.error.message);
+    }
+    return resp.data?.threads || [];
+}
+
+export const getChatHistoryThread = async (threadId: string): Promise<ChatThread> => {
+    const resp = await requestAPI<ChatThread>(`chat-history/threads/${threadId}`)
+    if (resp.error) {
+        throw new Error(resp.error.message);
+    }
+    return resp.data!;
 }
\ No newline at end of file
