@@ -5,14 +5,17 @@
 
 import { ChatHistoryManager, IDisplayOptimizedChatItem } from '../../Extensions/AiChat/ChatHistoryManager';
 import { IContextManager } from '../../Extensions/ContextManager/ContextManagerPlugin';
-import { INotebookTracker } from '@jupyterlab/notebook';
+import { INotebookTracker, NotebookPanel } from '@jupyterlab/notebook';
 
 // Mock the notebook utilities
 jest.mock('../../utils/notebook', () => ({
     getActiveCellCode: jest.fn(() => 'test code'),
     getActiveCellID: jest.fn(() => 'test-cell-id'),
+    getActiveCellIDInNotebookPanel: jest.fn(() => 'test-cell-id'),
     getAIOptimizedCells: jest.fn(() => []),
-    getCellCodeByID: jest.fn(() => 'test code')
+    getAIOptimizedCellsInNotebookPanel: jest.fn(() => []),
+    getCellCodeByID: jest.fn(() => 'test code'),
+    getCellCodeByIDInNotebookPanel: jest.fn(() => 'test code')
 }));
 
 // Mock the user utilities
@@ -23,6 +26,8 @@ jest.mock('../../utils/user', () => ({
 describe('ChatHistoryManager', () => {
     let mockContextManager: IContextManager;
     let mockNotebookTracker: INotebookTracker;
+    let mockNotebookPanel: NotebookPanel;
+    const mockNotebookId = '/test/notebook.ipynb';
 
     beforeEach(() => {
         // Reset all mocks
@@ -30,12 +35,20 @@ describe('ChatHistoryManager', () => {
 
         // Create mock context manager
         mockContextManager = {
-            variables: [],
-            files: [],
-            setVariables: jest.fn(),
-            setFiles: jest.fn()
+            getNotebookContext: jest.fn(),
+            getActiveNotebookContext: jest.fn(),
+            updateNotebookVariables: jest.fn(),
+            updateNotebookFiles: jest.fn()
         } as IContextManager;
 
+        // Create mock notebook panel
+        mockNotebookPanel = {
+            id: mockNotebookId,
+            context: {
+                sessionContext: { name: 'test-notebook' }
+            }
+        } as NotebookPanel;
+
         // Create mock notebook tracker
         mockNotebookTracker = {} as INotebookTracker;
     });
@@ -215,7 +228,7 @@ describe('ChatHistoryManager', () => {
         it('should add agent execution message', () => {
             const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker);
 
-            const metadata = manager.addAgentExecutionMessage('thread-123', 'Execute this');
+            const metadata = manager.addAgentExecutionMessage('thread-123', mockNotebookPanel, 'Execute this');
 
             expect(metadata.promptType).toBe('agent:execution');
             expect(metadata.input).toBe('Execute this');
@@ -234,7 +247,7 @@ describe('ChatHistoryManager', () => {
         it('should add agent smart debug message', () => {
             const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker);
 
-            const metadata = manager.addAgentSmartDebugMessage('thread-123', 'Agent error');
+            const metadata = manager.addAgentSmartDebugMessage('thread-123', 'Agent error', mockNotebookPanel);
 
             expect(metadata.promptType).toBe('agent:autoErrorFixup');
             expect(metadata.errorMessage).toBe('Agent error');
@@ -415,6 +428,25 @@ describe('ChatHistoryManager', () => {
             expect(history[1]?.agentResponse?.analysis_assumptions).toEqual(undefined);
             expect(history[2]?.agentResponse?.analysis_assumptions).toEqual(['assumption2']);
         });
-    });
 
+        it('should handle empty string assumptions', () => {
+            const chatHistoryManager = new ChatHistoryManager(
+                mockContextManager,
+                mockNotebookTracker
+            );
+
+            // Add first response with assumptions
+            const firstResponse = {
+                type: 'finished_task' as const,
+                message: 'First response',
+                analysis_assumptions: ['']
+            };
+            chatHistoryManager.addAIMessageFromAgentResponse(firstResponse);
+
+            const history = chatHistoryManager.getDisplayOptimizedHistory();
+
+            // Check that responses are handled correctly
+            expect(history[0]?.agentResponse?.analysis_assumptions).toEqual(undefined);
+        });
+    });
 }); 
\ No newline at end of file
