@@ -66,7 +66,8 @@ type CompletionRequestMetadata =
   IDeleteThreadMetadata |
   IAgentExecutionMetadata | 
   IAgentSmartDebugMetadata |
-  IUpdateModelConfigMetadata
+  IUpdateModelConfigMetadata |
+  IStopAgentMetadata
 
 export interface IChatMessageMetadata {
   promptType: 'chat'
@@ -171,6 +172,12 @@ export interface ICompletionRequest {
    * Whether to stream the completion or not.
    */
   stream: boolean;
+  /**
+   * Environment information from the client
+   */
+  environment?: {
+    isElectron: boolean;
+  };
 }
 
 export interface IUpdateModelConfigRequest extends ICompletionRequest {
@@ -183,6 +190,11 @@ export interface IUpdateModelConfigMetadata {
   model: string;
 }
 
+export interface IStopAgentMetadata {
+  promptType: 'stop_agent'
+  threadId: string
+}
+
 export interface IChatCompletionRequest extends ICompletionRequest {
   type: 'chat',
   metadata: IChatMessageMetadata
@@ -218,6 +230,11 @@ export interface IFetchHistoryCompletionRequest extends ICompletionRequest {
   metadata: IFetchHistoryMetadata
 }
 
+export interface IStopAgentCompletionRequest extends ICompletionRequest {
+  type: 'stop_agent'
+  metadata: IStopAgentMetadata
+}
+
 /**
  * AI capabilities.
  */
